@@ -4,7 +4,7 @@ ebuild internal constants
 
 from snakeoil.osutils import pjoin
 
-from .. import const
+from ..const import EBD_PATH
 
 incrementals = (
     "ACCEPT_KEYWORDS", "ACCEPT_LICENSE", "CONFIG_PROTECT",
@@ -25,7 +25,6 @@ metadata_keys = (
 
 WORLD_FILE = '/var/lib/portage/world'
 
-EBD_PATH = const._GET_CONST('EBD_PATH', '%(REPO_PATH)s/ebd')
 EBUILD_DAEMON_PATH = pjoin(EBD_PATH, "ebuild-daemon.bash")
 EBUILD_HELPERS_PATH = pjoin(EBD_PATH, "helpers")
 
