@@ -257,14 +257,18 @@ class DisabledSyncer(Syncer):
 
     disabled = True
 
-    def __init__(self, path, uri=None, **kwargs):
-        super().__init__(path, uri='', **kwargs)
+    def __init__(self, path, *args, **kwargs):
+        super().__init__(path, uri='')
+
+
+@configurable({'basedir': 'str', 'usersync': 'bool'}, typename='syncer')
+def DisabledSync(basedir, *args, **kwargs):
+    return DisabledSyncer(basedir)
 
 
 @configurable({'basedir': 'str', 'usersync': 'bool'}, typename='syncer')
 def AutodetectSyncer(basedir, **kwargs):
-    for plug in plugin.get_plugins('syncer'):
-        ret = plug.is_usable_on_filepath(basedir)
-        if ret is not None:
-            return plug(basedir, *ret, **kwargs)
+    for syncer_cls in plugin.get_plugins('syncer'):
+        if args := syncer_cls.is_usable_on_filepath(basedir):
+            return syncer_cls(basedir, *args, **kwargs)
     return DisabledSyncer(basedir, **kwargs)
